use std::env;
use anyhow::Result as anyResult;
use clap::Parser;
use rustpan::clean_in_dir;

#[derive(Parser, Debug)]
#[command(version, about = "It's not a dust pan, it's a rust pan. (A cargo cleaner)", long_about = None)]
struct Args {
    #[arg(short='d', long="days", default_value_t=30)]
    /// Days since last modified and/or last accessed
    days: u32,
    #[arg(short='f', long="force")]
    /// Clean the directory, ignoring last modified and/or last accessed
    force: bool,
}

fn main() -> anyResult<()> {
    let mut cli = Args::parse();
    if cli.days == 0 {
        println!("0 days, using --force instead");
        cli.force = true;
        cli.days = 30;
    }
    println!("Sweeping...");
    let cwd = env::current_dir()?;
    let cleaned = clean_in_dir(cwd, cli.force, cli.days as u64)?;
    if cleaned == 1 {
        println!("Cleaned 1 crate");
    } else {
        println!("Cleaned {} crates", cleaned);
    }
    Ok(())
}
